@@ -57,12 +57,11 @@ class EMR_EKSStack(Stack):
             "metadata":{"name": self.emr_namespace_fg},
         })
 
-        # Fargate profile
-        fgprofile = container.eks.FargateProfile(self, "MyProfile",
-                        cluster=self.cluster,
-                        selectors=[container.eks.Selector(namespace=self.emr_namespace_fg)]
-                    )
-        
+        # Fargate profile 
+        fgprofile = container.eks.FargateProfile(self, "SparkFargateProfile", cluster=self.cluster, 
+            selectors=[container.eks.Selector(namespace=self.emr_namespace_fg)]
+        )
+        self.cluster.add_fargate_profile("SparkFargateProfile", [container.eks.Selector(namespace=self.emr_namespace_fg)], fargate_profile_name="SparkFargateProfile")
 
         # Create k8s cluster role for EMR
         emrrole = self.cluster.add_manifest("emrrole", {
